# PE-Designer

Prime editing tools that consist of a reverse transcriptase linked with Cas9 nickase are capable of generating targeted insertions, deletions, and base conversions without producing DNA double strand breaks or requiring any donor DNA.


usage

    python3 pe-designer.py reference_fasta induced_fasta PAM_sequence reference_genome_directory


Example

    python3 pe-designer.py example_ref.fasta example_ind.fasta NGG /directory/of/reference/genome/
    
    
